:github_url: https://github.com/stephane-caron/pink/tree/main/doc/tasks.rst

.. _Tasks:

*****
Tasks
*****

Definition
==========

.. automodule:: pink.tasks.task
    :members:

Frame task
==========

.. automodule:: pink.tasks.frame_task
    :members:

Relative frame task
===================

.. automodule:: pink.tasks.relative_frame_task
    :members:

Joint coupling task
===================

.. automodule:: pink.tasks.joint_coupling_task
    :members:

Linear holonomic task
=====================

.. automodule:: pink.tasks.linear_holonomic_task
    :members:

Posture task
============

.. automodule:: pink.tasks.posture_task
    :members:
